@@ -33,7 +33,7 @@ def isDebian():
 	return os.path.exists("/etc/debian_version")
 	
 def isRHEL():
-	return os.path.exists("redhat-release")
+	return os.path.exists("/etc/redhat-release")
 
 def exShellCommand(argArray, processInput=''):
 	""" Wrapper to run and return output of a shell command """
