@@ -207,11 +207,18 @@ def _insert_jos_xprofiles(db, hubname, uid, fname, mname, lname, username, email
 	db.query_rowcount(sql, data)
 
 
-def _insert_jos_users_password(db, userid, pw):
+def _insert_jos_users_password(db, userid, password):
 	sql = "INSERT INTO jos_users_password (`user_id`, `passhash`) " 
 	sql += "VALUES (%s, %s)"
 	
-	data = (userid, hubzero.config.passwords.MD5PasswordHash(pw))
+        if password != '*':
+               pw = hubzero.config.passwords.MD5PasswordHash(password)
+        elif '{MD5}' in password:
+                pw = password
+        else:
+                pw = '{MD5}*' # can user generate a value that will MD5 hash to, we think not '*'?
+
+	data = (userid, pw)
 	db.query_rowcount(sql, data)
 
 
@@ -304,16 +311,16 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
 	fullName = gecosFields[0]
 	fullNameList = gecosFields[0].split(" ")
 	
-	if len(fullName) == 3:
-		firstName = fullName[0]
-		middleName = fullName[1]
-		lastName = fullName[2]
-	elif len(fullName) == 2:
-		firstName = fullName[0]
+	if len(fullNameList) == 3:
+		firstName = fullNameList[0]
+		middleName = fullNameList[1]
+		lastName = fullNameList[2]
+	elif len(fullNameList) == 2:
+		firstName = fullNameList[0]
 		middleName = ""
-		lastName = fullName[1]
-	elif len(fullName) == 1:
-		firstName = fullName[0]
+		lastName = fullNameList[1]
+	elif len(fullNameList) == 1:
+		firstName = fullNameList[0]
 		middleName = ""
 		lastName = ""
 	else:
